@@ -1,5 +1,5 @@
 package Test::BDD::Cucumber::Errors;
-$Test::BDD::Cucumber::Errors::VERSION = '0.24';
+$Test::BDD::Cucumber::Errors::VERSION = '0.25';
 use strict;
 use warnings;
 
@@ -13,7 +13,7 @@ Test::BDD::Cucumber::Errors - Consistently formatted errors
 
 =head1 VERSION
 
-version 0.24
+version 0.25
 
 =head1 DESCRIPTION
 
@@ -72,7 +72,7 @@ sub parse_error_from_line {
         _get_context_range( $line->document, $feature_line );
 
     my $formatted_lines;
-    for ( 0 .. 4 ) {
+    for ( 0 .. $#lines ) {
         my $actual_line = $start_line + $_;
         my $mark = ($feature_line == $actual_line) ? '*' : '|';
         $formatted_lines .=
@@ -116,6 +116,7 @@ sub _get_context_range {
 
     # Then cut it off
     @range = grep { $_ >= $min_range } @range;
+    @range = grep { $_ <= $max_range } @range;
 
     return( $range[0], map { $document->lines->[$_ - 1]->raw_content } @range );
 }
