@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Harness;
-$Test::BDD::Cucumber::Harness::VERSION = '0.24';
+$Test::BDD::Cucumber::Harness::VERSION = '0.25';
 =head1 NAME
 
 Test::BDD::Cucumber::Harness - Base class for creating harnesses
 
 =head1 VERSION
 
-version 0.24
+version 0.25
 
 =head1 DESCRIPTION
 
@@ -72,7 +72,10 @@ sub scenario_done { my ( $self, $scenario, $dataset ) = @_; }
 
 Called at the start and end of step execution respectively. Both methods
 accept a L<Test::BDD::Cucmber::StepContext> object. C<step_done> also accepts
-a L<Test::BDD::Cucumber::Model::Result> object.
+a L<Test::BDD::Cucumber::Model::Result> object and an arrayref of arrayrefs with
+locations of consolidated matches, for highlighting.
+
+ [ [2,5], [7,9] ]
 
 =cut
 
