@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Harness::Data;
-$Test::BDD::Cucumber::Harness::Data::VERSION = '0.24';
+$Test::BDD::Cucumber::Harness::Data::VERSION = '0.25';
 =head1 NAME
 
 Test::BDD::Cucumber::Harness::Data - Builds up an internal data representation of test passes / failures
 
 =head1 VERSION
 
-version 0.24
+version 0.25
 
 =head1 DESCRIPTION
 
@@ -128,9 +128,10 @@ sub step {
 }
 
 sub step_done {
-    my ($self, $context, $result) = @_;
+    my ($self, $context, $result, $highlights) = @_;
 
     $self->current_step->{'result'} = $result;
+    $self->current_step->{'highlights'} = $highlights;
     push( @{ $self->current_scenario->{'steps'} }, $self->current_step );
     $self->current_step({});
 }
